@@ -1,8 +1,11 @@
 package Flux::Simple::ArrayIn;
 {
-  $Flux::Simple::ArrayIn::VERSION = '1.00';
+  $Flux::Simple::ArrayIn::VERSION = '1.01';
 }
 
+# ABSTRACT: input stream representation of an array
+
+
 use Moo;
 with 'Flux::In';
 
@@ -40,11 +43,20 @@ __END__
 
 =head1 NAME
 
-Flux::Simple::ArrayIn
+Flux::Simple::ArrayIn - input stream representation of an array
 
 =head1 VERSION
 
-version 1.00
+version 1.01
+
+=head1 SYNOPSIS
+
+    use Flux::Simple::ArrayIn;
+    $in = Flux::Simple::ArrayIn->new(\@items);
+
+=head1 DESCRIPTION
+
+Usually, you shouldn't create instances of this class directly. Use C<array_in> helper from L<Flux::Simple> instead.
 
 =head1 AUTHOR
 
